/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: Pops, TCSDeveloper
 */

package com.topcoder.rules.dependencymap.view.stresstests;

import junit.framework.TestCase;
import com.topcoder.rules.dependencymap.view.*;
import java.util.*;
import java.io.File;

/**
 * Stress tests Task 4
 */
public class StressBlankColumnRemoval extends TestCase   {
    /**
    * Dependency purposely built during setup to have
    * a large number of sub-elements
    */
    Dependency myDependency;

    /**
    * number of levels the test dependency tree will have
    */
    private final int maxNumLevels = 6;

    /**
    * number of sub-elements for each level of the test dependency
     * this number is even so as to avoid the blank column issue
    */
    private final int maxNumElements = 4;

    /**
    * List of Diagram renderers
    */
    private DiagramRenderer sampleRenderer;

    /**
    * Template name for the test files
    */
    private final String fileName = "../../test_files/file00";

    /**
    * counter for number of dependants
    */
    private int totalCount;

    /**
     *
     */
    public void setUp()
    {
        sampleRenderer = new SVGRenderer(new File(fileName));
        //create the large dependency graph
        totalCount = 1;
        myDependency = new Dependency("evenChildrenDependency");
        Vector currentLevel = new Stack();
        currentLevel.add(myDependency);
        for(int i = 0; i < maxNumLevels; ++i)
        {
            Vector nextLevel = new Stack();
            while(!currentLevel.isEmpty())
            {
                Dependency current = (Dependency)currentLevel.firstElement();
                currentLevel.removeElementAt(0);
                for(int j = 0; j < maxNumElements; ++j)
                {
                    Dependency d = new Dependency("level " + i + " element " + j);
                    current.addDependant(d);
                    nextLevel.add(d);
                    ++totalCount;
                }
            }
            currentLevel = new Vector(nextLevel);
        }
    }

    /**
    * Removes the temporary files
    */
    public void tearDown()
    {
        File f = new File(fileName);
        f.delete();
    }

    /**
    * Attempts to render a large dependency graph
    */
    public void testEvenDescendants() throws RendererException
    {
        // Create the Dependency Renderer and add a diagram renderer
        DependencyRenderer renderer = new DependencyRenderer();
        renderer.addDiagramRenderer(sampleRenderer);
        long startTime = new Date().getTime();
        // Render the dependency
        renderer.render(myDependency);
        long ts = new Date().getTime() - startTime;
        System.out.println("Rendering a graph with even descendants " + maxNumLevels + " levels and " + maxNumElements + " elements per level  (total of " + totalCount + " elements) took " + ts + " ms");
    }
}
